@@ -31,5 +31,5 @@ else:
     if _has_google_profiler:
         from _release_build import __google_profiler_start, __google_profiler_stop
         
-logger.info('Loaded STEME C++-python interface from %s', S.__file__)
+logger.info('Loaded STEME C++-python interface from %s', S.__name__)
 
